* ------------------------------------------------------------------------------

* CIS - Community Innovation Survey, wave 2006 - Data without Boundaries

* This setup file converts the raw NORWAY data from CSV to SAV
* Checked for the July 2013 release of the CIS, as provided by Eurostat

* Version 3 of the file, April 2015
* Tested with SPSS version 17

* University of Bucharest, Romanian Social Data Archive
* Adrian Dusa
* http://www.roda.ro
* Contact: dusa.adrian@unibuc.ro

* ------------------------------------------------------------------------------





* ------------------------------------------------------------------------------

* --- CONFIGURATION SECTION - START ---


* The following command should contain the complete path and
* name of the .csv file to be read (e.g. "C:/CIS 2006/CSV/NO.csv")
* Change CSV_DATA_PATH to your filename, below:

FILE HANDLE csvpath /NAME="CSV_DATA_PATH" .


* The following command should contain the complete path and
* name of the .sav file to be saved (e.g. "C:/CIS 2006/SAV/NO.sav")
* Change SAV_DATA_PATH to your filename, below:

FILE HANDLE savfile /NAME="SAV_DATA_PATH" .


* --- CONFIGURATION SECTION -  END  ---

* ------------------------------------------------------------------------------



* There should be nothing to change below this line
* ------------------------------------------------------------------------------



* -------------- Start Definition Macro --------------

SET LOCALE = "English" .
SHOW LOCALE .

* --------------     Read Raw Data      --------------

GET DATA
 /TYPE=TXT
 /FILE=csvpath
 /DELCASE=LINE
 /ARRANGEMENT=DELIMITED
 /DELIMITERS=','
 /QUALIFIER='"'
 /FIRSTCASE=2
 /IMPORTCASE=ALL
 /VARIABLES=
RTOT_MSK F1.0
C_HO     F1.0
NACE_PRO A8
SIZE06   F1.0
SIZE04   F1.0
ID       F6.0
WEIGHT   F6.2
COUNTRY  A2
RRDINXM  F8.0
RRDEXXM  F8.0
RMACXM   F1.0
ROEKXM   F1.0
TURN04M  F9.0
TURN06M  F9.0
GP       F1.0
MARLOC   F1.0
MARNAT   F1.0
MAREUR   F1.0
MAROTH   F1.0
INPDGD   F1.0
INPDSV   F1.0
INPDTW   F1.0
NEWMKT   F1.0
NEWFRM   F1.0
TURNMAR  F4.2
TURNIN   F4.2
TURNUNG  F4.2
INPSPD   F1.0
INPSLG   F1.0
INPSSU   F1.0
INPCSW   F1.0
INONAB   F1.0
RRDIN    F1.0
RDENG    F1.0
RRDEX    F1.0
RMAC     F1.0
ROEK     F1.0
RTR      F1.0
RMAR     F1.0
RPRE     F1.0
FUNLOC   F1.0
FUNGMT   F1.0
FUNEU    F1.0
FUNRTD   F1.0
SENTG    F1.0
SSUP     F1.0
SCLI     F1.0
SCOM     F1.0
SINS     F1.0
SUNI     F1.0
SGMT     F1.0
SCON     F1.0
SJOU     F1.0
SPRO     F1.0
CO       F1.0
CO11     F1.0
CO12     F1.0
CO13     F1.0
CO14     F1.0
CO21     F1.0
CO22     F1.0
CO23     F1.0
CO24     F1.0
CO31     F1.0
CO32     F1.0
CO33     F1.0
CO34     F1.0
CO41     F1.0
CO42     F1.0
CO43     F1.0
CO44     F1.0
CO51     F1.0
CO52     F1.0
CO53     F1.0
CO54     F1.0
CO61     F1.0
CO62     F1.0
CO63     F1.0
CO64     F1.0
CO71     F1.0
CO72     F1.0
CO73     F1.0
CO74     F1.0
PMOS     A1
ERANGE   F1.0
EMAR     F1.0
EQUA     F1.0
EFLEX    F1.0
ECAP     F1.0
ELBR     F1.0
EMAT     F1.0
EENV     F1.0
ESTD     F1.0
HCON     F1.0
HBEG     F1.0
HDLAY    F1.0
HFENT    F1.0
HFOUT    F1.0
HCOS     F1.0
HPER     F1.0
HTEC     F1.0
HINF     F1.0
HPAR     F1.0
HDOM     F1.0
HDEM     F1.0
HPRIOR   F1.0
HMAR     F1.0
PROPAT   F1.0
PRODSG   F1.0
PROTM    F1.0
PROCP    F1.0 .
CACHE .
EXECUTE .

* ------------------------------------------------------------------------------


* --- Recode string variables which have labels, to numeric variables --- 
 
 
RECODE NACE_PRO ("C" = 1) ("DA" = 2) ("DB" = 3) ("DC" = 4) ("20_21" = 5) ("22" = 6) ("DF_DG" = 7)
                ("DH" = 8) ("DI" = 9) ("27" = 10) ("28" = 11) ("DK" = 12) ("DL" = 13) ("DM" = 14)
                ("DN" = 15) ("E" = 16) ("F" = 17)("50" = 18) ("51" = 19) ("52" = 20) ("H" = 21)
                ("60_61_62" = 22) ("63" = 23)("64" = 24) ("J" = 25) ("70" = 26) ("71" = 27)
                ("72" = 28) ("73_74" = 29) INTO TEMPVRBL .
EXECUTE .

ALTER TYPE NACE_PRO(F2.0) .

COMPUTE NACE_PRO = TEMPVRBL .
EXECUTE .

DELETE VARIABLES TEMPVRBL .
EXECUTE .

* Variable PMOS is completely empty, recoding command skipped.

ALTER TYPE PMOS(F1.0) .



* --- Add variable labels --- 

VARIABLE LABELS
WEIGHT   "Weighting factors"
COUNTRY  "Country"
CO62     "Universities or other higher education institutions: EU/EFTA/EU-CC"
C_HO     "Country of head office. ISO 3166 alphanumeric 2 digit code"
ID       "Name of enterprise"
NACE_PRO "Main activity"
RRDINXM  "Expenditure in intramural R&D"
RRDEXXM  "Expenditure in extramural R&D"
RMACXM   "Expenditure in acquisition of machinery"
ROEKXM   "Expenditure in other external knowledge"
RTOT_MSK "Total for four expenditure categories"
TURN04M  "Total turnover in 2004"
TURN06M  "Total turnover in 2006"
SIZE06   "Total number of employees in 2006"
SIZE04   "Total number of employees in 2004"
GP       "Enterprise part of a group"
MARLOC   "Local/regional market"
MARNAT   "National I market"
MAREUR   "Other EU/EFTA/CC market"
MAROTH   "All other countries"
INPDGD   "Introduced onto the market a new or significantly improved good"
INPDSV   "Introduced onto the market a new or significantly improved service"
INPDTW   "Who mainly developed these products"
NEWMKT   "Did the enterprise introduce a product new to the market"
NEWFRM   "Did the enterprise introduce a product new to the firm"
TURNMAR  "% of turnover in new or improved products introduced during 2004-2006 that were new to the market"
TURNIN   "% of turnover in unchanged or marginally modified products during  2004-2006 that were new to the firm"
TURNUNG  "% of turnover in unchanged or marginally modified products during 2004-2006"
INPSPD   "Introduced onto the market a new or significantly improved method of production"
INPSLG   "Introduced onto the market a new or significantly improved logistic, delivery or distribution system"
INPSSU   "Introduced onto the market a new or significantly improved supporting activities"
INPCSW   "Who mainly developed these processes"
INONAB   "Enterprise with ongoing or abandoned innovation activities"
RRDIN    "Engagement in intramural R&D"
RDENG    "Type of engagement in R&D"
RRDEX    "Engagement in extramural R&D"
RMAC     "Engagement in acquisition of machinery"
ROEK     "Engagement in other external knowledge"
RTR      "Engagement in training"
RMAR     "Engagement in market introduction of innovation"
RPRE     "Engagement in other preparation"
FUNLOC   "Public funding from local or regional autorities"
FUNGMT   "Public funding from central government"
FUNEU    "Public funding from the EU"
FUNRTD   "Public from EU's 5th or 6th RTD"
SENTG    "Sources from within the enterprise or enterprise group"
SSUP     "Sources from Suppliers of equipment, materials, etc"
SCLI     "Sources from Clients or customers"
SCOM     "Sources from Competitors and other enterprises of same industry"
SINS     "Sources from consultants, commercial labs or private R&D institutes"
SUNI     "Sources from Universities or other higher education institutes"
SGMT     "Sources from Government or public research institutes"
SCON     "Sources from professional conferences, trade fairs, meetings"
SJOU     "Sources from Scientific journals, trade/scientific publications"
SPRO     "Sources from Professional and industry associations"
CO       "Cooperation arrangements on innovation activities"
CO11     "Other enterprises within enterprise group: National"
CO12     "Other enterprises within enterprise group: EU/EFTA/EU-CC"
CO13     "Other enterprises within enterprise group: US"
CO14     "Other enterprises within enterprise group: Other countries"
CO21     "Suppliers of equipment, etc: National"
CO22     "Suppliers of equipment, etc: EU/EFTA/EU-CC"
CO23     "Suppliers of equipment, etc: US"
CO24     "Suppliers of equipment, etc: Other countries"
CO31     "Clients or customers: National"
CO32     "Clients or customers: EU/EFTA/EU-CC"
CO33     "Clients or customers : US"
CO34     "Clients or customers: Other countries"
CO41     "Competitors or other firms ... : National"
CO42     "Competitors or other firms ...: EU/EFTA/EU-CC"
CO43     "Competitors or other firms ...: US"
CO44     "Competitors or other firms ... : Other countries"
CO51     "Consultants, commercial labs, private R&D institutes: National"
CO52     "Consultants, commercial labs, private R&D institutes: EU/EFTA/EU-CC"
CO53     "Consultants, commercial labs, private R&D institutes: US"
CO54     "Consultants, commercial labs, private R&D institutes: Other countries"
CO61     "Universities or other ...: National"
CO63     "Universities or other ... : US"
CO64     "Universities or other ... : Other countries"
CO71     "Government or public research institutes: National"
CO72     "Government or public research institutes: EU/EFTA/EU-CC"
CO73     "Government or public research institutes: US"
CO74     "Government or public research institutes: Other countries"
PMOS     "Most important co-operation partner"
ERANGE   "Increased range of goods or services"
EMAR     "Increased market or market share"
EQUA     "Improved quality in goods or services"
EFLEX    "Improved production flexibility"
ECAP     "Increased production capacity"
ELBR     "Reduced labour costs per produced unit"
EMAT     "Reduced materials and energy per produced unit"
EENV     "Reduced environmental impact or health and safety aspects"
ESTD     "Met regulations or standards"
HCON     "Innovation activity abandoned at concept stage"
HBEG     "Innovation activity abandoned after the activity/project begun"
HDLAY    "Innovation activity seriously delayed"
HFENT    "Hampering factor: Lack of funds within enterprises or ent. group"
HFOUT    "Hampering factor : Lack of outside funds"
HCOS     "Hampering factor : Innovation costs too high"
HPER     "Hampering factor : Lack of qualified personnel"
HTEC     "Hampering factor : Lack of information on technology"
HINF     "Hampering factor : Lack of information on markets"
HPAR     "Hampering factor : Difficulty in finding co-operation partners"
HDOM     "Hampering factor : Market dominated by established enterprises"
HDEM     "Hampering factor: Uncertain demand for innovative goods/services"
HPRIOR   "No innovation activity due to prior innovations"
HMAR     "No innovation activity due to no demand for innovations"
PROPAT   "Applied for a patent"
PRODSG   "Registered an industrial design"
PROTM    "Register a trademark"
PROCP    "Claimed copyright" .
EXECUTE .


* --- Add value labels --- 

VALUE LABELS
CO62, GP, MARLOC, MARNAT, MAREUR, MAROTH, INPDGD, INPDSV, NEWMKT, NEWFRM, INPSPD, INPSLG,
INPSSU, INONAB, RRDIN, RRDEX, RMAC, ROEK, RTR, RMAR, RPRE, FUNLOC, FUNGMT, FUNEU,
FUNRTD, CO, CO11, CO12, CO13, CO14, CO21, CO22, CO23, CO24, CO31, CO32, CO33, CO34,
CO41, CO42, CO43, CO44, CO51, CO52, CO53, CO54, CO61, CO63, CO64, CO71, CO72, CO73,
CO74, HCON, HBEG, HDLAY, PROPAT, PRODSG, PROTM, PROCP
0 "No"
1 "Yes"
/
C_HO
0 "No answer"
1 "Home country"
2 "EU,EFTA,CC"
3 "rest of the world"
/
NACE_PRO
1 "Mining and quarrying"
2 "Manufacture of food products, beverages and tobacco"
3 "Manufacture of textiles and textile products"
4 "Manufacture of leather and leather products"
5 "Manufacture of wood and wood products; manufacture of pulp, paper and paper products"
6 "Publishing, printing and reproduction of recorded media"
7 "Manufacture of coke, refined petroleum products and nuclear fuel, of chemicals, chemical products and man-made fibres"
8 "Manufacture of rubber and plastic products"
9 "Manufacture of other non-metallic mineral products"
10 "Manufacture of basic metals"
11 "Manufacture of fabricated metal products, except machinery and equipment"
12 "Manufacture of machinery and equipment n.e.c."
13 "Manufacture of electrical and optical equipment"
14 "Manufacture of transport equipment"
15 "Manufacturing n.e.c."
16 "Electricity, gas and water supply"
17 "Construction"
18 "Sale, maintenance and repair of motor vehicles and motorcycles; retail sale of automotive fuel"
19 "Wholesale trade and commission trade, except of motor vehicles and motorcycles"
20 "Retail trade, except of motor vehicles and motorcycles; repair of personal and household goods"
21 "Hotels and restaurants"
22 "Land transport; transport via pipelines; water transport, air transport"
23 "Supporting and auxiliary transport activities; activities of travel agencies"
24 "Post and telecommunications"
25 "Financial intermediation"
26 "Real estate activities"
27 "Renting of machinery and equipment without operator and of personal and household goods"
28 "Computer and related activities"
29 "Research and development; other business activities"
/
SIZE06, SIZE04
0 "<50"
1 "50-249"
2 ">=250"
/
INPDTW, INPCSW
1 "Mainly by the enterprise or enterprise group"
2 "In cooperation with other enterprises or institutions"
3 "Mainly other enterprises or institutions"
/
RDENG
1 "Continuously"
2 "Occasionally"
/
SENTG, SSUP, SCLI, SCOM, SINS, SUNI, SGMT, SCON, SJOU, SPRO
0 "Not used"
1 "Low"
2 "Med"
3 "High"
/
PMOS
1 "Other enterprises within enterprise group"
2 "Suppliers of equipment, etc"
3 "Clients or customers"
4 "Competitors or other firms"
5 "Consultants, commercial labs, private R&D institutes"
6 "Universities or other ..."
7 "Government or public research institutes"
/
ERANGE, EMAR, EQUA, EFLEX, ECAP, ELBR, EMAT, EENV, ESTD, HFENT, HFOUT, HCOS, HPER,
HTEC, HINF, HPAR, HDOM, HDEM, HPRIOR, HMAR
0 "Not relevant"
1 "Low"
2 "Med"
3 "High" .
EXECUTE .


* --- Add missing values --- 

MISSING VALUES
C_HO, SENTG, SSUP, SCLI, SCOM, SINS, SUNI, SGMT, SCON, SJOU, SPRO, ERANGE, EMAR, EQUA,
EFLEX, ECAP, ELBR, EMAT, EENV, ESTD, HFENT, HFOUT, HCOS, HPER, HTEC, HINF, HPAR,
HDOM, HDEM, HPRIOR, HMAR (0) .


* --- Save the .sav file --- 

SAVE OUTFILE=savfile
/KEEP
RTOT_MSK
C_HO
NACE_PRO
SIZE06
SIZE04
ID
WEIGHT
COUNTRY
RRDINXM
RRDEXXM
RMACXM
ROEKXM
TURN04M
TURN06M
GP
MARLOC
MARNAT
MAREUR
MAROTH
INPDGD
INPDSV
INPDTW
NEWMKT
NEWFRM
TURNMAR
TURNIN
TURNUNG
INPSPD
INPSLG
INPSSU
INPCSW
INONAB
RRDIN
RDENG
RRDEX
RMAC
ROEK
RTR
RMAR
RPRE
FUNLOC
FUNGMT
FUNEU
FUNRTD
SENTG
SSUP
SCLI
SCOM
SINS
SUNI
SGMT
SCON
SJOU
SPRO
CO
CO11
CO12
CO13
CO14
CO21
CO22
CO23
CO24
CO31
CO32
CO33
CO34
CO41
CO42
CO43
CO44
CO51
CO52
CO53
CO54
CO61
CO62
CO63
CO64
CO71
CO72
CO73
CO74
PMOS
ERANGE
EMAR
EQUA
EFLEX
ECAP
ELBR
EMAT
EENV
ESTD
HCON
HBEG
HDLAY
HFENT
HFOUT
HCOS
HPER
HTEC
HINF
HPAR
HDOM
HDEM
HPRIOR
HMAR
PROPAT
PRODSG
PROTM
PROCP
  /COMPRESSED .
EXECUTE .
